pro html_get_files, htmldoc, filelist, recurse=recurse, $
    tarfile=tarfile, loud=loud, debug=debug, ppath=ppath, $
    striptemplate=striptemplate, rewrite=rewrite, original=original
;+
;   Name: html_get_files
;
;   Purpose: get relative files referenced by an html doc (recursive)
;
;   Input Parameters:
;      htmlparent - the top level .html document
;
;   Output Parameters
;      filelist - the relative filelist referenced by this htmldoc
;
;   Keyword Parameters:
;      tarfile - if set, write a tarfile (supply name or use as switch)
;      loud - if set, more verbose
;      ppath (output) - the parent path implied for htmldoc and filelist
;      striptemplate, rewrite, original - strip html header/trailer from 
;                     parent html (often site specific)
;                
;
;   Motivation:
;     Simplify relocation of an html doc and its local files
;         
;   Calls:
;      rd_tfile, strfind_urls, file_exist, str2arr, str_replace,
;      the usual suspecs.
;
;   Restrictions:
;      only gets those things (gif/mpeg/html...) which are
;      relative to input htmldoc.
;;
;   Side Effects:
;      may write a tar file
;
;-
common html_get_files, htmlparent, parentpath

recurse=keyword_set(recurse)
loud=keyword_set(loud)
debug=keyword_set(debug)
newparent=keyword_set(rewrite) or keyword_set(original) or keyword_set(striptemplate)

if loud then box_message,htmldoc

if not keyword_set(recurse) then begin 
   break_file, htmldoc, ll, parentpath, ff,vv,ee
   if parentpath eq '' then parentpath =curdir()

   if newparent then begin 
      if data_chk(rewrite,/string) then begin 
         break_file,rewrite,ll,pp
         if pp eq '' then rewrite=concat_dir(parentpath,rewrite)
         rewrite=str_replace(rewrite,'.html','') + '.html'
      endif 
      delvarx,newname
      html_remove_template, htmldoc, rewrite=rewrite, original=original, newname=newname
      if data_chk(newname,/string) then htmldoc=newname
   endif
   htmlparent=htmldoc
   filelist=htmldoc
   ppath=parentpath
endif

html=rd_tfile(htmldoc)
urls=strfind_urls(html)

exturl=strtrim(strextract(urls.url,'"'),2)
exturl=strmids(exturl,([0,1])(strpos(exturl,'/') eq 0),strlen(exturl))

fexist=file_exist(exturl)
ssno=where(1-fexist,ncnt)
if ncnt gt 0 then exturl(ssno)=concat_dir(parentpath,exturl(ssno))

fexist=file_exist(exturl)
ssexist=where(fexist,ecnt)
if ecnt gt 0 then exturl=exturl(ssexist) else exturl=""

sshtml=wc_where(exturl,'*.html',/case_ignore,mcount)
ssfinal=rem_elem(ssexist,sshtml,fincnt)

if fincnt gt 0 then begin 
   if not data_chk(filelist,/string) then filelist=exturl(ssfinal) else $
      filelist=[filelist,exturl(ssfinal)]
endif

if debug then stop,'filelist...'
 
for i=0,mcount-1 do $
   html_get_files, exturl(sshtml(i)), filelist, /recurse, loud=loud

filelist=filelist(uniqo(filelist))
notdir=where(1-is_dir(filelist))
filelist=filelist(notdir)

if debug then stop

if keyword_set(tarfile) then begin 
   case 1 of 
      data_chk(tarfile,/string): tarname=str_replace(tarfile,'.tar','') + '.tar'
      else: tarname=str_replace(htmlparent,'.html','.tar')
   endcase
   break_file,tarname,ll,pp,ff,vv,ee
   if pp eq '' then tarname=concat_dir('$HOME',tarname)
   break_file,filelist,ll,pp,ff,vv,ee
   relfiles=ff+vv+ee
   tarcmd=['tar','-cf',tarname,'-C',parentpath,relfiles]
   if loud then print,arr2str(tarcmd,' ')
   box_message,'Writing tar file: ' + tarname
   spawn,tarcmd,/noshell
endif


return
end


